spacepy.plot.utils.timestamp — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- plot - Plot, various specialized plotting functions and associated utilities »
- spacepy.plot.utils »

# spacepy.plot.utils.timestamp

`spacepy.plot.utils.` `timestamp`(position=[1.003, 0.01], size='xx-small', draw=True, **kwargs)

  print a timestamp on the current plot, vertical lower right

  Parameters: | position : list position for the timestamp size : string (optional) text size draw : Boolean (optional) call draw to make sure it appears kwargs : keywords other keywords to axis.annotate

  Examples

      >>> import spacepy.plot.utils
      >>> from pylab import plot, arange
      >>> plot(arange(11))
      [<matplotlib.lines.Line2D object at 0x49072b0>]
      >>> spacepy.plot.utils.timestamp()

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- plot - Plot, various specialized plotting functions and associated utilities »
- spacepy.plot.utils »